<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>EllipseInscribedQuad</name>
    <message>
        <location filename="../EllipseInscribedQuad.js" line="+82"/>
        <source>First line</source>
        <translation>第一条线</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Second line</source>
        <translation>第二条线</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Third line</source>
        <translation>第三条线</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Fourth line</source>
        <translation>第四条线</translation>
    </message>
    <message>
        <location filename="../EllipseInscribedQuadInit.js" line="+2"/>
        <source>Inscribed in Quadrilateral</source>
        <translation>内切于四边形</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw ellipse inscribed in quadrilateral</source>
        <translation>绘制内切于四边形的椭圆</translation>
    </message>
</context>
</TS>
